""" Wrapper to the YouTube API """

import logging

import googleapiclient.discovery
import wordfilter

import config

LOGGER = logging.getLogger(__name__)

def get_videos(query):
    """ Given a search query, return a list of video IDs """
    youtube = googleapiclient.discovery.build('youtube', 'v3',
                                              developerKey=config.API_KEY,
                                              cache_discovery=False)

    request = youtube.search().list(
        part="snippet",
        q=query,
        maxResults=100
    )
    response = request.execute()

    if 'items' not in response:
        LOGGER.warning("No items found")
        return []

    wfilter = wordfilter.Wordfilter()
    return [item["id"]["videoId"]
            for item in response['items']
            if 'id' in item
            and 'videoId' in item['id']
            and not wfilter.blacklisted(
                item['snippet'].get('title', '')
                + item['snippet'].get('description', ''))]


if __name__ == "__main__":
    print(get_videos("+lofi beats to chill and relax to"))
